@@ -1,4 +1,4 @@
-/*  Copyright (C) 2014-2020 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) CZ.NIC, z.s.p.o. <knot-resolver@labs.nic.cz>
  *  SPDX-License-Identifier: GPL-3.0-or-later
  */
 
@@ -1691,27 +1691,6 @@ static int qr_task_step(struct qr_task *task,
 	}
 }
 
-static int parse_packet(knot_pkt_t *query)
-{
-	if (!query){
-		return kr_error(EINVAL);
-	}
-
-	/* Parse query packet. */
-	int ret = knot_pkt_parse(query, 0);
-	if (ret == KNOT_ETRAIL) {
-		/* Extra data after message end. */
-		ret = kr_error(EMSGSIZE);
-	} else if (ret != KNOT_EOK) {
-		/* Malformed query. */
-		ret = kr_error(EPROTO);
-	} else {
-		ret = kr_ok();
-	}
-
-	return ret;
-}
-
 int worker_submit(struct session *session, struct io_comm_data *comm,
                   const uint8_t *eth_from, const uint8_t *eth_to, knot_pkt_t *pkt)
 {
@@ -1722,11 +1701,53 @@ int worker_submit(struct session *session, struct io_comm_data *comm,
 	if (!handle || !handle->loop->data)
 		return kr_error(EINVAL);
 
-	int ret = parse_packet(pkt);
-
-	const bool is_query = (knot_wire_get_qr(pkt->wire) == 0);
+	const bool is_query = pkt->size > KNOT_WIRE_OFFSET_FLAGS1
+				&& knot_wire_get_qr(pkt->wire) == 0;
 	const bool is_outgoing = session_flags(session)->outgoing;
 
+	int ret = 0;
+	if (is_query == is_outgoing)
+		ret = KNOT_ENOENT;
+
+	// For responses from upstream, try to find associated task and query.
+	// In case of errors, at least try to guess.
+	struct qr_task *task = NULL;
+	bool task_matched_id = false;
+	if (is_outgoing && pkt->size >= 2) {
+		const uint16_t id = knot_wire_get_id(pkt->wire);
+		task = session_tasklist_del_msgid(session, id);
+		task_matched_id = task != NULL;
+		if (task_matched_id) // Note receive time for RTT calculation
+			task->recv_time = kr_now();
+		if (!task_matched_id) {
+			ret = KNOT_ENOENT;
+			VERBOSE_MSG(NULL, "=> DNS message with mismatching ID %d\n",
+					(int)id);
+		}
+	}
+	if (!task && is_outgoing && handle->type == UV_TCP) {
+		// Source address of the reply got somewhat validated,
+		// so we try to at least guess which query, for error reporting.
+		task = session_tasklist_get_first(session);
+	}
+	struct kr_query *qry = NULL;
+	if (task)
+		qry = array_tail(task->ctx->req.rplan.pending);
+
+	// Parse the packet, unless it's useless anyway.
+	if (ret == 0) {
+		ret = knot_pkt_parse(pkt, 0);
+		if (ret == KNOT_ETRAIL && is_outgoing
+				&& !kr_fails_assert(pkt->parsed < pkt->size)) {
+			// We deal with this later, so that RCODE takes priority.
+			ret = 0;
+		}
+		if (ret && kr_log_is_debug_qry(WORKER, qry)) {
+			VERBOSE_MSG(qry, "=> DNS message failed to parse, %s\n",
+					knot_strerror(ret));
+		}
+	}
+
 	struct http_ctx *http_ctx = NULL;
 #if ENABLE_DOH2
 	http_ctx = session_http_get_server_ctx(session);
@@ -1734,26 +1755,28 @@ int worker_submit(struct session *session, struct io_comm_data *comm,
 	/* Badly formed query when using DoH leads to a Bad Request */
 	if (http_ctx && !is_outgoing && ret) {
 		http_send_status(session, HTTP_STATUS_BAD_REQUEST);
-		return ret;
+		return kr_error(ret);
 	}
 #endif
 
 	if (!is_outgoing && http_ctx && queue_len(http_ctx->streams) <= 0)
 		return kr_error(ENOENT);
 
+	const struct sockaddr *addr = comm ? comm->src_addr : NULL;
+
 	/* Ignore badly formed queries. */
-	if ((ret != kr_ok() && ret != kr_error(EMSGSIZE)) ||
-	    (is_query == is_outgoing)) {
-		if (!is_outgoing) {
+	if (ret) {
+		if (is_outgoing && qry) // unusuable response from somewhat validated IP
+			qry->server_selection.error(qry, task->transport, KR_SELECTION_MALFORMED);
+		if (!is_outgoing)
 			the_worker->stats.dropped += 1;
-		}
+		if (task_matched_id) // notify task that answer won't be coming anymore
+			qr_task_step(task, addr, NULL);
 		return kr_error(EILSEQ);
 	}
 
 	/* Start new task on listening sockets,
 	 * or resume if this is subrequest */
-	struct qr_task *task = NULL;
-	const struct sockaddr *addr = NULL;
 	if (!is_outgoing) { /* request from a client */
 		struct request_ctx *ctx =
 			request_create(the_worker, session, comm, eth_from,
@@ -1779,18 +1802,11 @@ int worker_submit(struct session *session, struct io_comm_data *comm,
 			return kr_error(ENOMEM);
 		}
 	} else { /* response from upstream */
-		const uint16_t id = knot_wire_get_id(pkt->wire);
-		task = session_tasklist_del_msgid(session, id);
 		if (task == NULL) {
-			VERBOSE_MSG(NULL, "=> ignoring packet with mismatching ID %d\n",
-					(int)id);
 			return kr_error(ENOENT);
 		}
 		if (kr_fails_assert(!session_flags(session)->closing))
 			return kr_error(EINVAL);
-		addr = (comm) ? comm->src_addr : NULL;
-		/* Note receive time for RTT calculation */
-		task->recv_time = kr_now();
 	}
 	if (kr_fails_assert(!uv_is_closing(session_get_handle(session))))
 		return kr_error(EINVAL);
@@ -2095,6 +2111,11 @@ struct request_ctx *worker_task_get_request(struct qr_task *task)
 	return task->ctx;
 }
 
+struct kr_transport *worker_task_get_transport(struct qr_task *task)
+{
+	return task->transport;
+}
+
 struct session *worker_request_get_source_session(const struct kr_request *req)
 {
 	static_assert(offsetof(struct request_ctx, req) == 0,
