@@ -1,17 +1,5 @@
-/*  Copyright (C) 2016-2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+/*  Copyright (C) CZ.NIC, z.s.p.o. <knot-resolver@labs.nic.cz>
+ *  SPDX-License-Identifier: GPL-3.0-or-later
  */
 /**
  * @file lru.h
@@ -63,9 +51,9 @@
 
 #pragma once
 
-#include <assert.h>
-#include <stdint.h>
+#include <stdalign.h>
 #include <stddef.h>
+#include <stdint.h>
 
 #include "contrib/ucw/lib.h"
 #include "lib/utils.h"
@@ -88,15 +76,25 @@
  * @param ptable pointer to a pointer to the LRU
  * @param max_slots number of slots
  * @param mm_ctx_array memory context to use for the huge array, NULL for default
+ * 	If you pass your own, it needs to produce CACHE_ALIGNED allocations (ubsan).
  * @param mm_ctx memory context to use for individual key-value pairs, NULL for default
  *
  * @note The pointers to memory contexts need to remain valid
  * 	during the whole life of the structure (or be NULL).
  */
+/* Pragmas: C11 only standardizes alignof on type names, not on expressions.
+ * That's a GNU extension; in clang it's supported but may generate warnings.
+ * It seems hard to disable warnings that are only supported by some compilers. */
 #define lru_create(ptable, max_slots, mm_ctx_array, mm_ctx) do { \
 	(void)(((__typeof__((*(ptable))->pdata_t))0) == (void *)0); /* typecheck lru_t */ \
+	_Pragma("GCC diagnostic push") \
+	_Pragma("GCC diagnostic ignored \"-Wpragmas\"") \
+	_Pragma("GCC diagnostic ignored \"-Wunknown-pragmas\"") \
+	_Pragma("GCC diagnostic ignored \"-Wgnu-alignof-expression\"") \
 	*(ptable) = (__typeof__(*(ptable))) \
-		lru_create_impl((max_slots), (mm_ctx_array), (mm_ctx)); \
+		lru_create_impl((max_slots), alignof(*( (*(ptable))->pdata_t )), \
+				(mm_ctx_array), (mm_ctx)); \
+	_Pragma("GCC diagnostic pop") \
 	} while (false)
 
 /** @brief Free an LRU created by lru_create (it can be NULL). */
@@ -163,15 +161,6 @@ enum lru_apply_do {
 #define lru_capacity(table) lru_capacity_impl(&(table)->lru)
 
 
-/** @brief Round the value up to a multiple of (1 << power). */
-static inline uint round_power(uint size, uint power)
-{
-	uint res = ((size - 1) & ~((1 << power) - 1)) + (1 << power);
-	assert(__builtin_ctz(res) >= power);
-	assert(size <= res && res < size + (1 << power));
-	return res;
-}
-
 
 /* ======================== Inlined part of implementation ======================== */
 /** @cond internal */
@@ -188,7 +177,8 @@ typedef lru_apply_fun_g(lru_apply_fun, void);
 
 struct lru;
 void lru_free_items_impl(struct lru *lru);
-struct lru * lru_create_impl(uint max_slots, knot_mm_t *mm_array, knot_mm_t *mm);
+struct lru * lru_create_impl(uint max_slots, uint val_alignment,
+			     knot_mm_t *mm_array, knot_mm_t *mm);
 void * lru_get_impl(struct lru *lru, const char *key, uint key_len,
 		    uint val_len, bool do_insert, bool *is_new);
 void lru_apply_impl(struct lru *lru, lru_apply_fun f, void *baton);
@@ -219,6 +209,7 @@ struct lru {
 	struct knot_mm *mm, /**< Memory context to use for keys. */
 		*mm_array; /**< Memory context to use for this structure itself. */
 	uint log_groups; /**< Logarithm of the number of LRU groups. */
+	uint val_alignment; /**< Alignment for the values. */
 	struct lru_group groups[] CACHE_ALIGNED; /**< The groups of items. */
 };
 
@@ -241,7 +232,7 @@ static inline void lru_reset_impl(struct lru *lru)
 /** @internal See lru_capacity. */
 static inline uint lru_capacity_impl(struct lru *lru)
 {
-	assert(lru);
+	kr_require(lru);
 	return (1 << lru->log_groups) * LRU_ASSOC;
 }
 
