@@ -1,17 +1,5 @@
-/*  Copyright (C) 2015-2017 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+/*  Copyright (C) CZ.NIC, z.s.p.o. <knot-resolver@labs.nic.cz>
+ *  SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 /** @file
@@ -31,11 +19,11 @@ struct kr_prop;
 /**
  * Export module API version (place this at the end of your module).
  *
- * @param module module name (f.e. hints)
+ * @param module module name (e.g. policy)
  */
 #define KR_MODULE_EXPORT(module) \
     KR_EXPORT uint32_t module ## _api() { return KR_MODULE_API; }
-#define KR_MODULE_API ((uint32_t) 0x20180401)
+#define KR_MODULE_API ((uint32_t) 0x20210125)
 
 typedef uint32_t (module_api_cb)(void);
 
@@ -49,19 +37,29 @@ typedef uint32_t (module_api_cb)(void);
 struct kr_module {
 	char *name;
 
-	/** Constructor.  Called after loading the module.  @return error code. */
+	/** Constructor.  Called after loading the module.  @return error code.
+	 * Lua modules: not populated, called via lua directly. */
 	int (*init)(struct kr_module *self);
+
 	/** Destructor.  Called before unloading the module.  @return error code. */
 	int (*deinit)(struct kr_module *self);
-	/** Configure with encoded JSON (NULL if missing).  @return error code. */
-	int (*config)(struct kr_module *self, const char *input);
-	/** Get a pointer to packet processing API specs.  See docs on that type. */
-	const kr_layer_api_t * (*layer)(struct kr_module *self);
-	/** Get a pointer to list of properties, terminated by { NULL, NULL, NULL }. */
-	const struct kr_prop * (*props)(void);
 
-	void *lib;      /**< Shared library handle or RTLD_DEFAULT */
-	void *data;     /**< Custom data context. */
+	/** Configure with encoded JSON (NULL if missing).  @return error code.
+	 * Lua modules: not used and not useful from C.
+	 * When called from lua, input is JSON, like for kr_prop_cb. */
+	int (*config)(struct kr_module *self, const char *input);
+
+	/** Packet processing API specs.  May be NULL.  See docs on that type.
+	 * Owned by the module code. */
+	const kr_layer_api_t *layer;
+
+	/** List of properties.  May be NULL.  Terminated by { NULL, NULL, NULL }.
+	 * Lua modules: not used and not useful. */
+	const struct kr_prop *props;
+
+	/** dlopen() handle; RTLD_DEFAULT for embedded modules; NULL for lua modules. */
+	void *lib;
+	void *data; /**< Custom data context. */
 };
 
 /**
@@ -70,7 +68,8 @@ struct kr_module {
  * @param env pointer to the lua engine, i.e. struct engine *env (TODO: explicit type)
  * @param input parameter (NULL if missing/nil on lua level)
  * @return a free-form JSON output (malloc-ated)
- * @note see l_trampoline() implementation for details about the input/output conversion.
+ * @note see modules_create_table_for_c() implementation for details
+ *       about the input/output conversion.
  */
 typedef char *(kr_prop_cb)(void *env, struct kr_module *self, const char *input);
 
@@ -85,9 +84,9 @@ struct kr_prop {
 
 
 /**
- * Load a C module instance into memory.
+ * Load a C module instance into memory.  And call its init().
  *
- * @param module module structure
+ * @param module module structure.  Will be overwritten except for ->data on success.
  * @param name module name
  * @param path module search path
  * @return 0 or an error
@@ -99,13 +98,15 @@ int kr_module_load(struct kr_module *module, const char *name, const char *path)
  * Unload module instance.
  *
  * @param module module structure
+ * @note currently used even for lua modules
  */
 KR_EXPORT
 void kr_module_unload(struct kr_module *module);
 
+typedef int (*kr_module_init_cb)(struct kr_module *);
 /**
- * Get embedded module prototype by name (or NULL).
+ * Get embedded module's init function by name (or NULL).
  */
 KR_EXPORT
-const struct kr_module * kr_module_embedded(const char *name);
+kr_module_init_cb kr_module_get_embedded(const char *name);
 
