@@ -1,4 +1,4 @@
-/*  Copyright (C) 2014-2021 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) CZ.NIC, z.s.p.o. <knot-resolver@labs.nic.cz>
  *  SPDX-License-Identifier: GPL-3.0-or-later
  */
 
@@ -248,6 +248,20 @@ int kr_pkt_put(knot_pkt_t *pkt, const knot_dname_t *name, uint32_t ttl,
 KR_EXPORT
 void kr_pkt_make_auth_header(knot_pkt_t *pkt);
 
+/** Get pointer to the in-header QNAME.
+ *
+ * That's normally not lower-cased.  However, when receiving packets from upstream
+ * we xor-apply the secret during packet-parsing, so it would get lower-cased
+ * after that point if the case was right.
+ */
+static inline knot_dname_t * kr_pkt_qname_raw(const knot_pkt_t *pkt)
+{
+	if (pkt == NULL || pkt->qname_size == 0) {
+		return NULL;
+	}
+	return pkt->wire + KNOT_WIRE_HEADER_SIZE;
+}
+
 /** Simple storage for IPx address and their ports or AF_UNSPEC. */
 union kr_sockaddr {
 	struct sockaddr ip;
@@ -391,13 +405,6 @@ static inline bool kr_sockaddr_link_local(const struct sockaddr *addr)
 	return kr_bitcmp((char *) ip6->sin6_addr.s6_addr, (char *) prefix, 10) == 0;
 }
 
-/** @internal RR map flags. */
-static const uint8_t KEY_FLAG_RRSIG = 0x02;
-static inline uint8_t KEY_FLAG_RANK(const char *key)
-	{ return ((uint8_t)(key[0])) >> 2; }
-static inline bool KEY_COVERING_RRSIG(const char *key)
-	{ return ((uint8_t)(key[0])) & KEY_FLAG_RRSIG; }
-
 /* Stash key = {[5] class, [1-255] owner, [5] type, [5] additional, [1] \x00 } */
 #define KR_RRKEY_LEN (16 + KNOT_DNAME_MAXLEN)
 /** Create unique null-terminated string key for RR.
