@@ -40,7 +40,7 @@ def create_file_from_template(template_path, dest, data):
     template = env.get_template(template_path)
     rendered_template = template.render(**data)
 
-    with open(dest, "w") as fh:
+    with open(dest, "w", encoding='UTF-8') as fh:
         fh.write(rendered_template)
 
 
@@ -92,7 +92,7 @@ class Kresd(ContextDecorator):
             self.tls_port = make_port(self.ip, self.ip6)
 
         create_file_from_template(KRESD_CONF_TEMPLATE, self.config_path, {'kresd': self})
-        self.logfile = open(self.logfile_path, 'w')
+        self.logfile = open(self.logfile_path, 'w', encoding='UTF-8')
         self.process = subprocess.Popen(
             ['kresd', '-c', self.config_path, '-n', self.workdir],
             stderr=self.logfile, env=os.environ.copy())
@@ -112,7 +112,7 @@ class Kresd(ContextDecorator):
                 raise RuntimeError("Kresd crashed with returncode: {}".format(
                     self.process.returncode))
         except (RuntimeError, ConnectionError):  # pylint: disable=try-except-raise
-            with open(self.logfile_path) as log:  # print log for debugging
+            with open(self.logfile_path, encoding='UTF-8') as log:  # print log for debugging
                 print(log.read())
             raise
 
@@ -147,7 +147,7 @@ class Kresd(ContextDecorator):
         while time.time() < end_time:
             i += 1
 
-            # use exponential backoff algorhitm to choose next delay
+            # use exponential backoff algorithm to choose next delay
             rand_delay = random.randrange(0, i)
             time.sleep(rand_delay * delay_step)
 
@@ -220,8 +220,8 @@ class Kresd(ContextDecorator):
         return self._tls_socket_with_retry(socket.AF_INET6)
 
     def partial_log(self):
-        partial_log = '\n (... ommiting log start)\n'
-        with open(self.logfile_path) as log:  # display partial log for debugging
+        partial_log = '\n (... omitting log start)\n'
+        with open(self.logfile_path, encoding='UTF-8') as log:  # display partial log for debugging
             past_startup_msgid = False
             past_startup = False
             for line in log:
@@ -251,7 +251,7 @@ def is_port_free(port, ip=None, ip6=None):
             check(socket.AF_INET6, socket.SOCK_STREAM, (ip6, port, 0, 0))
             check(socket.AF_INET6, socket.SOCK_DGRAM, (ip6, port, 0, 0))
     except OSError as exc:
-        if exc.errno == 98:  # address alrady in use
+        if exc.errno == 98:  # address already in use
             return False
         else:
             raise
